@@ -25,13 +25,6 @@ suite('CookiesPageTest', function() {
   let page: SettingsCookiesPageElement;
   let settingsPrefs: SettingsPrefsElement;
 
-  function primarySettingGroup(): SettingsRadioGroupElement {
-    const group = page.shadowRoot!.querySelector<SettingsRadioGroupElement>(
-        '#primarySettingGroup');
-    assertTrue(!!group);
-    return group;
-  }
-
   function thirdPartyCookieBlockingSettingGroup(): SettingsRadioGroupElement {
     const group = page.shadowRoot!.querySelector<SettingsRadioGroupElement>(
         '#thirdPartyCookieBlockingSettingGroup');
@@ -39,32 +32,18 @@ suite('CookiesPageTest', function() {
     return group;
   }
 
-  function blockThirdParty(): SettingsCollapseRadioButtonElement {
-    const blockThirdParty = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#blockThirdParty');
-    assertTrue(!!blockThirdParty);
-    return blockThirdParty;
-  }
-
-  function blockThirdPartyIncognito(): SettingsCollapseRadioButtonElement {
-    const blockThirdPartyIncognito = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#blockThirdPartyIncognito');
-    assertTrue(!!blockThirdPartyIncognito);
-    return blockThirdPartyIncognito;
-  }
-
-  function allowThirdParty(): SettingsCollapseRadioButtonElement {
-    const allowThirdParty = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#allowThirdParty');
-    assertTrue(!!allowThirdParty);
-    return allowThirdParty;
-  }
-
   function blockAll3pc(): SettingsCollapseRadioButtonElement {
-    const blockAll3pc = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#blockAll3pc');
+    const blockAll3pc =
+        page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>(
+            '#blockAll3pc');
     assertTrue(!!blockAll3pc);
     return blockAll3pc;
   }
 
   function block3pcIncognito(): SettingsCollapseRadioButtonElement {
-    const block3pcIncognito = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#block3pcIncognito');
+    const block3pcIncognito =
+        page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>(
+            '#block3pcIncognito');
     assertTrue(!!block3pcIncognito);
     return block3pcIncognito;
   }
@@ -76,10 +55,8 @@ suite('CookiesPageTest', function() {
     // Enable one of the PS APIs.
     page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
     page.set(
-      'prefs.profile.cookie_controls_mode.value', CookieControlsMode.OFF);
-    page.set(
-      'prefs.generated.third_party_cookie_blocking_setting.value',
-      ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+        'prefs.generated.third_party_cookie_blocking_setting.value',
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
     document.body.appendChild(page);
     flush();
   }
@@ -112,7 +89,232 @@ suite('CookiesPageTest', function() {
     Router.getInstance().resetRouteForTesting();
   });
 
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
+
+  test('ElementVisibility', async function() {
+    await flushTasks();
+    assertTrue(isChildVisible(page, '#explanationText'));
+    assertTrue(isChildVisible(page, '#generalControls'));
+    assertTrue(isChildVisible(page, '#additionalProtections'));
+    assertTrue(isChildVisible(page, '#exceptionHeader3pcd'));
+    assertTrue(isChildVisible(page, '#allow3pcExceptionsList'));
+    // Controls
+    assertTrue(isChildVisible(page, '#doNotTrack'));
+    assertTrue(isChildVisible(page, '#blockAll3pc'));
+    assertTrue(isChildVisible(page, '#block3pcIncognito'));
+    // Mode B only
+    assertFalse(isChildVisible(page, '#blockThirdPartyToggle'));
+    assertFalse(isChildVisible(page, '#allowThirdParty'));
+  });
+
+
+  test('thirdPartyCookiesRadioClicksRecorded', async function() {
+    blockAll3pc().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
+    let result =
+        await testMetricsBrowserProxy.whenCalled('recordSettingsPageHistogram');
+    assertEquals(PrivacyElementInteractions.THIRD_PARTY_COOKIES_BLOCK, result);
+    assertEquals(
+        'Settings.ThirdPartyCookies.Block',
+        await testMetricsBrowserProxy.whenCalled('recordAction'));
+    testMetricsBrowserProxy.reset();
+
+    block3pcIncognito().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+    result =
+        await testMetricsBrowserProxy.whenCalled('recordSettingsPageHistogram');
+    assertEquals(
+        PrivacyElementInteractions.THIRD_PARTY_COOKIES_BLOCK_IN_INCOGNITO,
+        result);
+    assertEquals(
+        'Settings.ThirdPartyCookies.Allow',
+        await testMetricsBrowserProxy.whenCalled('recordAction'));
+    testMetricsBrowserProxy.reset();
+  });
+
+
+  test('privacySandboxToast', async function() {
+    loadTimeData.overrideValues({
+      isPrivacySandboxRestricted: false,
+    });
+    resetRouterForTesting();
+    await createPage();
+    assertFalse(page.$.toast.open);
+
+    // Disabling 3P cookies should display the privacy sandbox toast.
+    page.set(
+        'prefs.generated.third_party_cookie_blocking_setting.value',
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+    blockAll3pc().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
+    assertTrue(page.$.toast.open);
+
+    // Re-enabling 3P cookies should not display the toast.
+    block3pcIncognito().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+    assertFalse(page.$.toast.open);
+
+    // The toast should not be displayed if the user has any privacy sandbox
+    // APIs disabled.
+    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', false);
+    blockAll3pc().click();
+    await flushTasks();
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
+    assertFalse(page.$.toast.open);
+
+    // Reset the state to show the toast.
+    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
+    page.set(
+        'prefs.generated.third_party_cookie_blocking_setting.value',
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+    blockAll3pc().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
+    assertTrue(page.$.toast.open);
+
+    // Reselecting a non-3P cookie blocking setting should hide the toast.
+    block3pcIncognito().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        page.getPref('generated.third_party_cookie_blocking_setting.value'),
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
+    assertFalse(page.$.toast.open);
+  });
+
+  test('privacySandboxToast_restrictedSandbox', async function() {
+    // No toast should be shown if the privacy sandbox is restricted.
+    loadTimeData.overrideValues({
+      isPrivacySandboxRestricted: true,
+    });
+    resetRouterForTesting();
+    await createPage();
+
+    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
+    blockAll3pc().click();
+    assertEquals(
+        'Settings.ThirdPartyCookies.Block',
+        await testMetricsBrowserProxy.whenCalled('recordAction'));
+    testMetricsBrowserProxy.resetResolver('recordAction');
+    assertFalse(page.$.toast.open);
+  });
+
+  test('disabledRWSToggle', async () => {
+    // Verify the RWS toggle is enabled iff the user has selected block 3PCs.
+    const relatedWebsiteSetsToggle =
+        page.shadowRoot!.querySelector<SettingsToggleButtonElement>(
+            '#relatedWebsiteSetsToggle3pcSetting')!;
+    blockAll3pc().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY,
+        page.prefs.generated.third_party_cookie_blocking_setting.value);
+    assertFalse(
+        relatedWebsiteSetsToggle.disabled, 'expect toggle to be enabled');
+
+    block3pcIncognito().click();
+    await eventToPromise('change', thirdPartyCookieBlockingSettingGroup());
+    await flushTasks();
+    assertEquals(
+        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY,
+        page.prefs.generated.third_party_cookie_blocking_setting.value);
+    assertTrue(
+        relatedWebsiteSetsToggle.disabled, 'expect toggle to be disabled');
+  });
+});
+
+// TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
+suite('CookiesPageTest_alwaysBlock3pcsIncognitoDisabled', function() {
+  let siteSettingsBrowserProxy: TestSiteSettingsPrefsBrowserProxy;
+  let testMetricsBrowserProxy: TestMetricsBrowserProxy;
+  let page: SettingsCookiesPageElement;
+  let settingsPrefs: SettingsPrefsElement;
+
+  function primarySettingGroup(): SettingsRadioGroupElement {
+    const group = page.shadowRoot!.querySelector<SettingsRadioGroupElement>(
+        '#primarySettingGroup');
+    assertTrue(!!group);
+    return group;
+  }
+
+  function blockThirdParty(): SettingsCollapseRadioButtonElement {
+    const blockThirdParty = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#blockThirdParty');
+    assertTrue(!!blockThirdParty);
+    return blockThirdParty;
+  }
+
+  function blockThirdPartyIncognito(): SettingsCollapseRadioButtonElement {
+    const blockThirdPartyIncognito = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#blockThirdPartyIncognito');
+    assertTrue(!!blockThirdPartyIncognito);
+    return blockThirdPartyIncognito;
+  }
+
+  function allowThirdParty(): SettingsCollapseRadioButtonElement {
+    const allowThirdParty = page.shadowRoot!.querySelector<SettingsCollapseRadioButtonElement>('#allowThirdParty');
+    assertTrue(!!allowThirdParty);
+    return allowThirdParty;
+  }
+
+
+  function createPage() {
+    page = document.createElement('settings-cookies-page');
+    page.prefs = settingsPrefs.prefs!;
+
+    // Enable one of the PS APIs.
+    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
+    page.set(
+      'prefs.profile.cookie_controls_mode.value', CookieControlsMode.OFF);
+    document.body.appendChild(page);
+    flush();
+  }
+
+  suiteSetup(function() {
+    settingsPrefs = document.createElement('settings-prefs');
+    return CrSettingsPrefs.initialized;
+  });
+
+  setup(function() {
+    // This test is for the pre-3PCD cookies page.
+    loadTimeData.overrideValues({
+      is3pcdCookieSettingsRedesignEnabled: false,
+      isAlwaysBlock3pcsIncognitoEnabled: false,
+    });
+    resetRouterForTesting();
+
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
+
+    testMetricsBrowserProxy = new TestMetricsBrowserProxy();
+    MetricsBrowserProxyImpl.setInstance(testMetricsBrowserProxy);
+    siteSettingsBrowserProxy = new TestSiteSettingsPrefsBrowserProxy();
+    SiteSettingsPrefsBrowserProxyImpl.setInstance(siteSettingsBrowserProxy);
+
+    createPage();
+  });
+
+  teardown(function() {
+    page.remove();
+    Router.getInstance().resetRouteForTesting();
+  });
+
   test('ElementVisibility_alwaysBlock3pcsIncognitoDisabled', async function() {
     loadTimeData.overrideValues({
       isAlwaysBlock3pcsIncognitoEnabled: false,
@@ -134,23 +336,6 @@ suite('CookiesPageTest', function() {
     assertFalse(isChildVisible(page, '#blockThirdPartyToggle'));
   });
 
-  test('ElementVisibility', async function() {
-    await flushTasks();
-    // Headers
-    assertTrue(isChildVisible(page, '#explanationText'));
-    assertTrue(isChildVisible(page, '#generalControls'));
-    assertTrue(isChildVisible(page, '#additionalProtections'));
-    assertTrue(isChildVisible(page, '#exceptionHeader3pcd'));
-    assertTrue(isChildVisible(page, '#allow3pcExceptionsList'));
-    // Settings
-    assertTrue(isChildVisible(page, '#doNotTrack'));
-    assertTrue(isChildVisible(page, '#blockAll3pc'));
-    assertTrue(isChildVisible(page, '#block3pcIncognito'));
-    // By default these toggles should be hidden.
-    assertFalse(isChildVisible(page, '#blockThirdPartyToggle'));
-  });
-
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
   test('ThirdPartyCookiesRadioClicksRecorded_alwaysBlock3pcsIncognitoDisabled', async function() {
     loadTimeData.overrideValues({
       isAlwaysBlock3pcsIncognitoEnabled: false,
@@ -159,7 +344,7 @@ suite('CookiesPageTest', function() {
     await createPage();
 
     blockThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
         CookieControlsMode.BLOCK_THIRD_PARTY);
@@ -169,7 +354,7 @@ suite('CookiesPageTest', function() {
     testMetricsBrowserProxy.reset();
 
     blockThirdPartyIncognito().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
         CookieControlsMode.INCOGNITO_ONLY);
@@ -181,7 +366,7 @@ suite('CookiesPageTest', function() {
     testMetricsBrowserProxy.reset();
 
     allowThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
         CookieControlsMode.OFF);
@@ -191,40 +376,6 @@ suite('CookiesPageTest', function() {
     testMetricsBrowserProxy.reset();
   });
 
-  test('thirdPartyCookiesRadioClicksRecorded', async function() {
-        blockAll3pc().click();
-        await eventToPromise(
-            'selected-changed', thirdPartyCookieBlockingSettingGroup());
-        assertEquals(
-            page.getPref('generated.third_party_cookie_blocking_setting.value'),
-            ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
-        let result = await testMetricsBrowserProxy.whenCalled(
-            'recordSettingsPageHistogram');
-        assertEquals(
-            PrivacyElementInteractions.THIRD_PARTY_COOKIES_BLOCK, result);
-        assertEquals(
-              'Settings.ThirdPartyCookies.Block',
-              await testMetricsBrowserProxy.whenCalled('recordAction'));
-        testMetricsBrowserProxy.reset();
-
-        block3pcIncognito().click();
-        await eventToPromise(
-            'selected-changed', thirdPartyCookieBlockingSettingGroup());
-        assertEquals(
-            page.getPref('generated.third_party_cookie_blocking_setting.value'),
-            ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-        result = await testMetricsBrowserProxy.whenCalled(
-            'recordSettingsPageHistogram');
-        assertEquals(
-            PrivacyElementInteractions.THIRD_PARTY_COOKIES_BLOCK_IN_INCOGNITO,
-            result);
-        assertEquals(
-              'Settings.ThirdPartyCookies.Allow',
-              await testMetricsBrowserProxy.whenCalled('recordAction'));
-        testMetricsBrowserProxy.reset();
-      });
-
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
   test('privacySandboxToast_alwaysBlock3pcsIncognitoDisabled', async function() {
     loadTimeData.overrideValues({
       isAlwaysBlock3pcsIncognitoEnabled: false,
@@ -235,7 +386,7 @@ suite('CookiesPageTest', function() {
 
     // Disabling third-party cookies should display the privacy sandbox toast.
     blockThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     await flushTasks();
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
@@ -251,7 +402,7 @@ suite('CookiesPageTest', function() {
 
     // Re-enabling 3P cookies for regular sessions should not display the toast.
     blockThirdPartyIncognito().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     await flushTasks();
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
@@ -274,7 +425,7 @@ suite('CookiesPageTest', function() {
         'prefs.profile.cookie_controls_mode.value',
         CookieControlsMode.INCOGNITO_ONLY);
     blockThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     await flushTasks();
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
@@ -284,7 +435,7 @@ suite('CookiesPageTest', function() {
 
     // Reselecting a non-3P cookie blocking setting should hide the toast.
     allowThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     await flushTasks();
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
@@ -294,7 +445,7 @@ suite('CookiesPageTest', function() {
     // Navigating away from the page should hide the toast, even if navigated
     // back to.
     blockThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     await flushTasks();
     assertEquals(
         page.getPref('profile.cookie_controls_mode.value'),
@@ -306,97 +457,8 @@ suite('CookiesPageTest', function() {
     assertFalse(page.$.toast.open);
   });
 
-  test('privacySandboxToast', async function() {
-    loadTimeData.overrideValues({
-      isPrivacySandboxRestricted: false,
-    });
-    resetRouterForTesting();
-    await createPage();
-    assertFalse(page.$.toast.open);
 
-    // Disabling third-party cookies should display the privacy sandbox toast.
-    page.set(
-        'prefs.generated.third_party_cookie_blocking_setting.value',
-        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-    blockAll3pc().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        page.getPref('generated.third_party_cookie_blocking_setting.value'),
-        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
-    assertTrue(page.$.toast.open);
-
-    // Re-enabling 3P cookies for regular sessions should not display the toast.
-    block3pcIncognito().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        page.getPref('generated.third_party_cookie_blocking_setting.value'),
-        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-    assertFalse(page.$.toast.open);
-
-    // The toast should not be displayed if the user has any privacy sandbox
-    // APIs disabled.
-    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', false);
-    blockAll3pc().click();
-    await flushTasks();
-    assertEquals(
-        page.getPref('generated.third_party_cookie_blocking_setting.value'),
-        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
-    assertFalse(page.$.toast.open);
-
-    // Reset the state to show the toast.
-    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
-    page.set(
-        'prefs.generated.third_party_cookie_blocking_setting.value',
-        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-    blockAll3pc().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        page.getPref('generated.third_party_cookie_blocking_setting.value'),
-        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY);
-    assertTrue(page.$.toast.open);
-
-    // Reselecting a non-3P cookie blocking setting should hide the toast.
-    block3pcIncognito().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        page.getPref('generated.third_party_cookie_blocking_setting.value'),
-        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-    assertFalse(page.$.toast.open);
-  });
-
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
-  test('privacySandboxToast_restrictedSandbox_alwaysBlock3pcsIncognitoDisabled', async function() {
-    // No toast should be shown if the privacy sandbox is restricted
-    loadTimeData.overrideValues({
-      isPrivacySandboxRestricted: true,
-      isAlwaysBlock3pcsIncognitoEnabled: false,
-    });
-    resetRouterForTesting();
-    await createPage();
-
-    page.set('prefs.privacy_sandbox.m1.topics_enabled.value', true);
-    blockThirdParty().click();
-    assertEquals(
-        'Settings.PrivacySandbox.Block3PCookies',
-        await testMetricsBrowserProxy.whenCalled('recordAction'));
-    testMetricsBrowserProxy.resetResolver('recordAction');
-    assertFalse(page.$.toast.open);
-  });
-
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
   test('disabledRWSToggle_alwaysBlock3pcsIncognitoDisabled', async () => {
-    loadTimeData.overrideValues({
-      isAlwaysBlock3pcsIncognitoEnabled: false,
-    });
-    resetRouterForTesting();
     await createPage();
     // Confirm that when the user has not selected the block 3PC setting, the
     // RWS toggle is disabled.
@@ -404,7 +466,7 @@ suite('CookiesPageTest', function() {
         page.shadowRoot!.querySelector<SettingsToggleButtonElement>(
             '#relatedWebsiteSetsToggle')!;
     blockThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         CookieControlsMode.BLOCK_THIRD_PARTY,
         page.prefs.profile.cookie_controls_mode.value);
@@ -412,65 +474,20 @@ suite('CookiesPageTest', function() {
         relatedWebsiteSetsToggle.disabled, 'expect toggle to be enabled');
 
     allowThirdParty().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         CookieControlsMode.OFF, page.prefs.profile.cookie_controls_mode.value);
     assertTrue(
         relatedWebsiteSetsToggle.disabled, 'expect toggle to be disabled');
 
     blockThirdPartyIncognito().click();
-    await eventToPromise('selected-changed', primarySettingGroup());
+    await eventToPromise('change', primarySettingGroup());
     assertEquals(
         CookieControlsMode.INCOGNITO_ONLY,
         page.prefs.profile.cookie_controls_mode.value);
     assertTrue(
         relatedWebsiteSetsToggle.disabled, 'expect toggle to be disabled');
   });
-
-  test('disabledRWSToggle', async () => {
-// Verify the RWS toggle is enabled iff the user has selected block 3PCs.
-    const relatedWebsiteSetsToggle =
-        page.shadowRoot!.querySelector<SettingsToggleButtonElement>(
-            '#relatedWebsiteSetsToggle3pcSetting')!;
-    blockAll3pc().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        ThirdPartyCookieBlockingSetting.BLOCK_THIRD_PARTY,
-        page.prefs.generated.third_party_cookie_blocking_setting.value);
-    assertFalse(
-        relatedWebsiteSetsToggle.disabled, 'expect toggle to be enabled');
-
-    block3pcIncognito().click();
-    await eventToPromise(
-        'selected-changed', thirdPartyCookieBlockingSettingGroup());
-    await flushTasks();
-    assertEquals(
-        ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY,
-        page.prefs.generated.third_party_cookie_blocking_setting.value);
-    assertTrue(
-        relatedWebsiteSetsToggle.disabled, 'expect toggle to be disabled');
-  });
-
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
-  test('blockThirdPartyIncognitoSecondBulletPointText_alwaysBlock3pcsIncognitoDisabled', async function() {
-    loadTimeData.overrideValues({
-      isAlwaysBlock3pcsIncognitoEnabled: false,
-    });
-    resetRouterForTesting();
-    await createPage();
-
-    // Confirm the correct string is set.
-    const cookiesPageBlockThirdPartyIncognitoBulTwo =
-        page.shadowRoot!
-            .querySelector<HTMLElement>(
-                '#blockThirdPartyIncognitoBulTwo');
-    assertTrue(!!cookiesPageBlockThirdPartyIncognitoBulTwo);
-    assertEquals(
-        loadTimeData.getString('cookiePageBlockThirdIncognitoBulTwoRws'),
-        cookiesPageBlockThirdPartyIncognitoBulTwo.innerText.trim());
-  });
 });
 
 suite('ExceptionsList', function() {
