@@ -6,40 +6,43 @@
 import 'chrome://settings/lazy_load.js';
 
 import {webUIListenerCallback} from 'chrome://resources/js/cr.js';
-// <if expr="not is_chromeos">
-import {listenOnce} from 'chrome://resources/js/util.js';
-// </if>
-
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
-// <if expr="not is_chromeos">
-import type {CrCheckboxElement} from 'chrome://settings/lazy_load.js';
-// </if>
-
 import {loadTimeData} from 'chrome://settings/settings.js';
-
 import type {SettingsPeoplePageElement} from 'chrome://settings/settings.js';
-import {pageVisibility, ProfileInfoBrowserProxyImpl, Router, routes, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
+import {ProfileInfoBrowserProxyImpl, resetRouterForTesting, Router, routes, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
 import {assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
-// <if expr="not is_chromeos">
-import {assertLT} from 'chrome://webui-test/chai_assert.js';
-import {flushTasks} from 'chrome://webui-test/polymer_test_util.js';
-import {waitBeforeNextRender} from 'chrome://webui-test/polymer_test_util.js';
-// </if>
 
 import {simulateSyncStatus} from './sync_test_util.js';
-// <if expr="not is_chromeos">
-import {simulateStoredAccounts} from './sync_test_util.js';
-// </if>
-
 import {TestProfileInfoBrowserProxy} from './test_profile_info_browser_proxy.js';
 import {TestSyncBrowserProxy} from './test_sync_browser_proxy.js';
 
+// <if expr="not is_chromeos">
+import {listenOnce} from 'chrome://resources/js/util.js';
+import type {CrCheckboxElement} from 'chrome://settings/lazy_load.js';
+import {assertLT} from 'chrome://webui-test/chai_assert.js';
+import {flushTasks, waitBeforeNextRender} from 'chrome://webui-test/polymer_test_util.js';
+import type {StoredAccount} from 'chrome://settings/settings.js';
+import { isChildVisible } from 'chrome://webui-test/test_util.js';
+
+import {simulateStoredAccounts} from './sync_test_util.js';
+// </if>
+
 // clang-format on
 
 let peoplePage: SettingsPeoplePageElement;
 let profileInfoBrowserProxy: TestProfileInfoBrowserProxy;
 let syncBrowserProxy: TestSyncBrowserProxy;
 
+function reset() {
+  peoplePage.remove();
+  loadTimeData.overrideValues({
+    signinAllowed: true,
+    replaceSyncPromosWithSignInPromos: false,
+  });
+  resetRouterForTesting();
+  Router.getInstance().navigateTo(routes.BASIC);
+}
+
 suite('ProfileInfoTests', function() {
   suiteSetup(function() {
     // <if expr="is_chromeos">
@@ -59,7 +62,6 @@ suite('ProfileInfoTests', function() {
 
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     peoplePage = document.createElement('settings-people-page');
-    peoplePage.pageVisibility = pageVisibility || {};
     document.body.appendChild(peoplePage);
 
     await syncBrowserProxy.whenCalled('getSyncStatus');
@@ -68,7 +70,7 @@ suite('ProfileInfoTests', function() {
   });
 
   teardown(function() {
-    peoplePage.remove();
+    reset();
   });
 
   test('GetProfileInfo', function() {
@@ -111,12 +113,11 @@ suite('SigninDisallowedTests', function() {
 
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     peoplePage = document.createElement('settings-people-page');
-    peoplePage.pageVisibility = pageVisibility || {};
     document.body.appendChild(peoplePage);
   });
 
   teardown(function() {
-    peoplePage.remove();
+    reset();
   });
 
   test('ShowCorrectRows', async function() {
@@ -140,9 +141,6 @@ suite('SigninDisallowedTests', function() {
 
 suite('SyncStatusTests', function() {
   setup(function() {
-    loadTimeData.overrideValues({
-      signinAllowed: true,
-    });
     syncBrowserProxy = new TestSyncBrowserProxy();
     SyncBrowserProxyImpl.setInstance(syncBrowserProxy);
 
@@ -151,12 +149,11 @@ suite('SyncStatusTests', function() {
 
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     peoplePage = document.createElement('settings-people-page');
-    peoplePage.pageVisibility = pageVisibility || {};
     document.body.appendChild(peoplePage);
   });
 
   teardown(function() {
-    peoplePage.remove();
+    reset();
   });
 
   test('Toast', function() {
@@ -179,45 +176,31 @@ suite('SyncStatusTests', function() {
     assertFalse(!!peoplePage.shadowRoot!.querySelector('#profile-row'));
 
     // The control element should exist when policy allows.
-    const accountControl =
-        peoplePage.shadowRoot!.querySelector('settings-sync-account-control')!;
-    assertTrue(window.getComputedStyle(accountControl)['display'] !== 'none');
+    assertTrue(isChildVisible(peoplePage, 'settings-sync-account-control'));
 
     // Control element doesn't exist when policy forbids sync.
     simulateSyncStatus({
       syncSystemEnabled: false,
       statusAction: StatusAction.NO_ACTION,
     });
-    assertEquals('none', window.getComputedStyle(accountControl)['display']);
-
-    const manageGoogleAccount =
-        peoplePage.shadowRoot!.querySelector('#manage-google-account')!;
-
-    // Do not show Google Account when stored accounts or sync status
-    // could not be retrieved.
-    simulateStoredAccounts(undefined);
-    simulateSyncStatus(undefined);
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
 
+    // Do not show Google Account when sync status could not be retrieved.
     simulateStoredAccounts([]);
     simulateSyncStatus(undefined);
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
-
-    simulateStoredAccounts(undefined);
-    simulateSyncStatus({
-      statusAction: StatusAction.NO_ACTION,
-    });
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
 
     simulateStoredAccounts([]);
     simulateSyncStatus({
       statusAction: StatusAction.NO_ACTION,
     });
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
+
+    simulateStoredAccounts([]);
+    simulateSyncStatus({
+      statusAction: StatusAction.NO_ACTION,
+    });
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
 
     // A stored account with sync off but no error should result in the
     // Google Account being shown.
@@ -227,8 +210,7 @@ suite('SyncStatusTests', function() {
       hasError: false,
       statusAction: StatusAction.NO_ACTION,
     });
-    assertTrue(
-        window.getComputedStyle(manageGoogleAccount)['display'] !== 'none');
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
 
     // A stored account with sync off and error should not result in the
     // Google Account being shown.
@@ -238,8 +220,7 @@ suite('SyncStatusTests', function() {
       hasError: true,
       statusAction: StatusAction.NO_ACTION,
     });
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
 
     // A stored account with sync on but no error should result in the
     // Google Account being shown.
@@ -249,8 +230,7 @@ suite('SyncStatusTests', function() {
       hasError: false,
       statusAction: StatusAction.NO_ACTION,
     });
-    assertTrue(
-        window.getComputedStyle(manageGoogleAccount)['display'] !== 'none');
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
 
     // A stored account with sync on but with error should not result in
     // the Google Account being shown.
@@ -260,8 +240,7 @@ suite('SyncStatusTests', function() {
       hasError: true,
       statusAction: StatusAction.NO_ACTION,
     });
-    assertEquals(
-        'none', window.getComputedStyle(manageGoogleAccount)['display']);
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
   });
 
   test('SignOutNavigationNormalProfile', async function() {
@@ -431,7 +410,6 @@ suite('SyncSettings', function() {
 
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     peoplePage = document.createElement('settings-people-page');
-    peoplePage.pageVisibility = pageVisibility || {};
     document.body.appendChild(peoplePage);
 
     await syncBrowserProxy.whenCalled('getSyncStatus');
@@ -439,12 +417,13 @@ suite('SyncSettings', function() {
   });
 
   teardown(function() {
-    peoplePage.remove();
+    reset();
   });
 
   test('ShowCorrectSyncRow', function() {
     assertTrue(!!peoplePage.shadowRoot!.querySelector('#sync-setup'));
     assertFalse(!!peoplePage.shadowRoot!.querySelector('#sync-status'));
+    assertFalse(!!peoplePage.shadowRoot!.querySelector('#google-services'));
 
     // Make sures the subpage opens even when logged out or has errors.
     simulateSyncStatus({
@@ -458,3 +437,177 @@ suite('SyncSettings', function() {
     assertEquals(Router.getInstance().getCurrentRoute(), routes.SYNC);
   });
 });
+
+// <if expr="not is_chromeos">
+suite('PeoplePageAccountSettings', function() {
+  setup(function() {
+    loadTimeData.overrideValues({replaceSyncPromosWithSignInPromos: true});
+    resetRouterForTesting();
+
+    syncBrowserProxy = new TestSyncBrowserProxy();
+    SyncBrowserProxyImpl.setInstance(syncBrowserProxy);
+
+    profileInfoBrowserProxy = new TestProfileInfoBrowserProxy();
+    ProfileInfoBrowserProxyImpl.setInstance(profileInfoBrowserProxy);
+
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
+    peoplePage = document.createElement('settings-people-page');
+    document.body.appendChild(peoplePage);
+  });
+
+  teardown(function() {
+    reset();
+  });
+
+  async function simulateSignedInState(
+      state: SignedInState, accounts: StoredAccount[]) {
+    await syncBrowserProxy.whenCalled('getSyncStatus');
+    simulateSyncStatus({
+      signedInState: state,
+      syncSystemEnabled: true,
+      hasError: false,
+      statusAction: StatusAction.NO_ACTION,
+    });
+    await flush();
+
+    await syncBrowserProxy.whenCalled('getStoredAccounts');
+    simulateStoredAccounts(accounts);
+    return flush();
+  }
+
+  test('ShowCorrectRowsSignedIn', async function() {
+    await simulateSignedInState(
+        SignedInState.SIGNED_IN, [{email: 'foo@foo.com'}]);
+
+    // The account card and the profile should not exist. Instead, there is a
+    // link row which leads to the account settings page.
+    assertFalse(isChildVisible(peoplePage, 'settings-sync-account-control'));
+    assertFalse(isChildVisible(peoplePage, '#profile-row'));
+    assertTrue(isChildVisible(peoplePage, '#account-subpage-row'));
+
+    // There is a link to the Google services, not to the sync settings.
+    assertTrue(isChildVisible(peoplePage, '#google-services'));
+    assertFalse(isChildVisible(peoplePage, '#sync-setup'));
+
+    // The other rows are shown correctly.
+    assertTrue(isChildVisible(peoplePage, '#edit-profile'));
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
+  });
+
+  test('ShowCorrectRowsSignedOut', async function() {
+    await simulateSignedInState(SignedInState.SIGNED_OUT, []);
+
+    // The first item should be an account card.
+    assertTrue(isChildVisible(peoplePage, 'settings-sync-account-control'));
+    assertFalse(isChildVisible(peoplePage, '#profile-row'));
+    assertFalse(isChildVisible(peoplePage, '#account-subpage-row'));
+
+    // There is a link to the Google services, not to the sync settings.
+    assertTrue(isChildVisible(peoplePage, '#google-services'));
+    assertFalse(isChildVisible(peoplePage, '#sync-setup'));
+
+    // The other rows are shown correctly.
+    assertTrue(isChildVisible(peoplePage, '#edit-profile'));
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
+    assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
+  });
+
+  test('ShowCorrectRowsSyncing', async function() {
+    await simulateSignedInState(
+        SignedInState.SYNCING, [{email: 'foo@foo.com'}]);
+
+    // The first item should be an account card.
+    assertTrue(isChildVisible(peoplePage, 'settings-sync-account-control'));
+    assertFalse(isChildVisible(peoplePage, '#profile-row'));
+    assertFalse(isChildVisible(peoplePage, '#account-subpage-row'));
+
+    // There is a link to the sync settings, not to the Google services.
+    assertFalse(isChildVisible(peoplePage, '#google-services'));
+    assertTrue(isChildVisible(peoplePage, '#sync-setup'));
+
+    // The other rows are shown correctly.
+    assertTrue(isChildVisible(peoplePage, '#edit-profile'));
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
+  });
+
+  test('ShowCorrectRowsSignInPending', async function() {
+    await simulateSignedInState(
+        SignedInState.SIGNED_IN_PAUSED, [{email: 'foo@foo.com'}]);
+
+    assertTrue(isChildVisible(peoplePage, 'settings-sync-account-control'));
+    assertFalse(isChildVisible(peoplePage, '#profile-row'));
+    assertFalse(isChildVisible(peoplePage, '#account-subpage-row'));
+
+    // There is a link to the Google services, not to the sync settings.
+    assertTrue(isChildVisible(peoplePage, '#google-services'));
+    assertFalse(isChildVisible(peoplePage, '#sync-setup'));
+
+    // The other rows are shown correctly.
+    assertTrue(isChildVisible(peoplePage, '#edit-profile'));
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
+  });
+
+  test('ShowCorrectRowsWebSignedIn', async function() {
+    await simulateSignedInState(
+        SignedInState.WEB_ONLY_SIGNED_IN, [{email: 'foo@foo.com'}]);
+
+    // The first item should be an account card.
+    assertTrue(isChildVisible(peoplePage, 'settings-sync-account-control'));
+
+    // There is a link to the Google services, not to the sync settings.
+    assertTrue(isChildVisible(peoplePage, '#google-services'));
+    assertFalse(isChildVisible(peoplePage, '#sync-setup'));
+
+    // The other rows are shown correctly.
+    assertTrue(isChildVisible(peoplePage, '#edit-profile'));
+    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
+  });
+
+  test('ClickingAccountLinkRowLeadsToAccountSettings', async function() {
+    await simulateSignedInState(
+        SignedInState.SIGNED_IN, [{email: 'foo@foo.com'}]);
+
+    peoplePage.shadowRoot!.querySelector<HTMLElement>(
+                              '#account-subpage-row')!.click();
+    assertEquals(routes.ACCOUNT, Router.getInstance().getCurrentRoute());
+  });
+
+  test('ClickingGoogleServicesLeadsToGoogleServicesPage', async function() {
+    await simulateSignedInState(SignedInState.SIGNED_OUT, []);
+
+    peoplePage.shadowRoot!.querySelector<HTMLElement>(
+                              '#google-services')!.click();
+    assertEquals(
+        routes.GOOGLE_SERVICES, Router.getInstance().getCurrentRoute());
+  });
+
+  test('AccountLinkRowHasAccountInfo', async function() {
+    const expectedAccount = {
+      fullName: 'Test Name',
+      email: 'test@email.com',
+      avatarImage: 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAA' +
+          'AAABAAEAAAICTAEAOw==',
+    };
+    await simulateSignedInState(SignedInState.SIGNED_IN, [expectedAccount]);
+
+    const accountName =
+        peoplePage.shadowRoot!.querySelector(
+                                  '#account-name')!.textContent!.trim();
+    const accountEmail =
+        peoplePage.shadowRoot!.querySelector(
+                                  '#account-email')!.textContent!.trim();
+
+    assertEquals(expectedAccount.fullName, accountName);
+    assertEquals(expectedAccount.email, accountEmail);
+
+    const bgImage =
+        peoplePage.shadowRoot!.querySelector<HTMLElement>(
+                                  '#profile-icon')!.style.backgroundImage;
+    assertTrue(bgImage.includes(expectedAccount.avatarImage));
+  });
+});
+// </if>
